# 正規表現でtextファイルと同じやり方で読み込むのですべて手打ちする．

from .ternary_diagram import *

__version__      = '1.4.0'
__license__      = 'MIT'
__author__       = 'yu-9824'
__copyright__ = 'Copyright (c) 2021 yu-9824'
__author_email__ = 'yu.9824.job@gmail.com'
__user_id__ = 'yu-9824'
__app_name__ = 'ternary_diagram'
__url__ = 'http://github.com/yu-9824/ternary_diagram/'

__all__ = [
    'TernaryDiagram',
]